<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="58"/>
        <location filename="../defaultlook.cpp" line="527"/>
        <location filename="../defaultlook.cpp" line="534"/>
        <location filename="../defaultlook.cpp" line="551"/>
        <location filename="../defaultlook.cpp" line="562"/>
        <location filename="../defaultlook.cpp" line="572"/>
        <source>MX Tweak</source>
        <translation>MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="54"/>
        <source>Xfce Settings</source>
        <translation>Настройки Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="63"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Настроить панель&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="77"/>
        <location filename="../defaultlook.ui" line="283"/>
        <source>Panel</source>
        <translation>Панель</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="97"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Настроить поведение окон и сочетания клавиш&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="111"/>
        <source>Window Manager</source>
        <translation>Оконный менеджер</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="131"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Персонализация рабочего стола&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="145"/>
        <source>Appearance</source>
        <translation>Внешний вид</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="223"/>
        <source>About</source>
        <translation>О приложении</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="234"/>
        <source>Help</source>
        <translation>Справка</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="251"/>
        <source>Quit application</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="254"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="261"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="291"/>
        <source>Options</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="311"/>
        <source>Backup current panel configuration</source>
        <translation>Сохранить текущую конфигурацию панели</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="318"/>
        <source>Restore backup panel configuration</source>
        <translation>Восстановить конфигурацию панели</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="325"/>
        <source>Restore default panel</source>
        <translation>Вернуть панель по умолчанию</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="338"/>
        <source>Affects 1st panel</source>
        <translation>Влияет на первую панель</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="345"/>
        <source>Display panel vertically</source>
        <translation>Вертикальное расположение</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="365"/>
        <source>Bottom</source>
        <translation>Внизу</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="370"/>
        <source>Top</source>
        <translation>Сверху</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="378"/>
        <source>Display panel horizontally</source>
        <translation>Горизонтальное расположение</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="398"/>
        <source>Left</source>
        <translation>Слева</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="403"/>
        <source>Right</source>
        <translation>Справа</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="411"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Влияет на все панели&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="431"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Кнопки окон&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="446"/>
        <location filename="../defaultlook.ui" line="549"/>
        <location filename="../defaultlook.ui" line="740"/>
        <location filename="../defaultlook.ui" line="894"/>
        <location filename="../defaultlook.ui" line="936"/>
        <source>Apply</source>
        <translation>Применить</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="469"/>
        <source>Theme</source>
        <translation>Тема</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="483"/>
        <source>Theme Options</source>
        <translation>Параметры темы</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="513"/>
        <source>Fix some website fields when using dark theme</source>
        <translation>Исправлять некоторые поля веб-сайтов при использовании темной темы</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="516"/>
        <source>Firefox dark theme tweak</source>
        <translation>Настройка темной темы Firefox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="523"/>
        <source>Fix HexChat input box in dark theme</source>
        <translation>Исправить поле ввода HexChat для темной темы</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="575"/>
        <source>Undo</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="582"/>
        <source>Preview</source>
        <translation>Предпросмотр</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="589"/>
        <source>Remove User Theme Set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="600"/>
        <source>Save Current Settings as a Theme Set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="614"/>
        <location filename="../defaultlook.ui" line="760"/>
        <source>Compositor</source>
        <translation>Композитор</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="635"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Запустить конфигуратор compton-conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="638"/>
        <source>Compton settings</source>
        <translation>Настройки Compton</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="662"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Настройки композитора Xfce&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="665"/>
        <source>Xfwm Settings</source>
        <translation>Настройки Xfmw</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="689"/>
        <source>None</source>
        <translation>Никакой</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="694"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Композитор Xfwm (Xfce)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="699"/>
        <source>Compton </source>
        <translation>Compton</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="707"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Редактировать compton.conf в текстовом редакторе</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="710"/>
        <source>Edit compton.conf</source>
        <translation>Редактировать compton.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="767"/>
        <source>Transparency and shadow options</source>
        <translation>Параметры прозрачности и теней</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="774"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="777"/>
        <source>VBlank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="785"/>
        <source>auto</source>
        <translation>авторежим</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="790"/>
        <source>glx</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="795"/>
        <source>xpresent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="800"/>
        <source>off</source>
        <translation>выкл.</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="811"/>
        <source>Config Options</source>
        <translation>Опции конфигурации</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="819"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Сбросить Lightdm (экран логина) к системной теме по умолчанию</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="826"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Сбросить на предустановленные действия по правому клику в Thunar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="833"/>
        <source>Use intel driver instead of default &quot;modsetting&quot; driver (requires restart)</source>
        <translation>Использовать драйвер intel вместо штатного &quot;modsetting&quot; драйвера (необходим перезапуск)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="840"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>ПРИМЕЧАНИЕ: существующий /etc/X11/xorg.conf.d/20-intel.conf будет сохранен в домашней директории</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="847"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Использовать опцию amdgpu видео без тиринга</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="854"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>ПРИМЕЧАНИЕ: существующий /etc/X11/xorg.conf.d/20-amd.conf будет скопирован в домашний каталог</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="861"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Использовать опцию драйвера radeon видео без тиринга</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="868"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>ПРИМЕЧАНИЕ: существующий /etc/X11/xorg.conf.d/20-radeon.conf будет скопирован в домашний каталог</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="908"/>
        <source>Other</source>
        <translation>Другое</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="916"/>
        <source>Enable single-click on desktop</source>
        <translation>Задействовать одиночный клик на рабочем столе</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="923"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Задействовать одиночный клик в Thunar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="960"/>
        <source>Show systray (notification area) frame</source>
        <translation>Отображать рамку systray (область уведомлений)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="967"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Показывать на панели окна со всех рабочих столов</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="974"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Включить монтирование внешних носителей для не-рут пользователей</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="981"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>Отключить укорачивание длинных имен на рабочем столе</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="988"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Добавить hibernate в меню Выхода из системы</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="995"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>примечание: для hibernate необходим swap &gt;= RAM</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="526"/>
        <source>About MX Tweak</source>
        <translation>О MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="527"/>
        <source>Version: </source>
        <translation>Версия: </translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="528"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Приложение для доводки штатного оформления и твиков</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="530"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="531"/>
        <location filename="../defaultlook.cpp" line="534"/>
        <source>License</source>
        <translation>Лицензия</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="532"/>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="563"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Готово! Может потребоваться перезапуск Firefox</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="573"/>
        <source>This app is Xfce-only</source>
        <translation>Приложение только для Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="715"/>
        <source>Panel settings</source>
        <translation>Настройки панели</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="716"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation type="vanished">Текущие настройки панели были сохранены в скрытой папке .restore вашего домашнего каталога (~/.restore/)</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1160"/>
        <source>Choose a theme set</source>
        <translation>Выберите набор темы</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="37"/>
        <source>Window Buttons</source>
        <translation>Кнопки окон</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Внешний вид&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Показывать подписи кнопок</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Показывать плоские кнопки</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Показывать ручку</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Порядок сортировки:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Метка времени</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Сгруппировать название и метку времени</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Заголовок окна</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Сгруппировать название приложения и заголовок окна</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Отсутствует, использовать перетаскивание</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Поведение&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Группировать окна:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Никогда</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Всегда</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Действие по щелчку средней кнопкой мыши:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Ничего</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Закрыть окно</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Свернуть окно</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Разворачивать свёрнутые окна на текущий рабочий стол</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Отображать рамку окна под курсором мыши</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Переключать окна с помощью колёсика мыши</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Фильтрация&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Показывать окна со всех рабочих мест или видов</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Показывать только свёрнутые окна</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Показывать окна со всех мониторов</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Диалоговое окно</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Всплывающие окна</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Окна при перетаскивании</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Настройки непрозрачности&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Оформление окон</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Отображать тени у уменьшенных (dock) окон</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Отображать тени у всплывающих окон</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Окна при изменении размеров</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Отображать тени у обычных окон</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Настройки возможностей&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Показывать превью окна вместо иконок при прокрутке</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Напрямую отображать полноэкранные оверлей окна</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Неактивные окна</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Синхронизировать отрисовку по вертикальной очистке</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="39"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Настройки композитора Xfwm</translation>
    </message>
</context>
</TS>
